unit QuizzFile;

interface

uses IniFiles, Classes;

type
  TQuizz = class(THashedStringList)
  private
    FLangue1,
    FLangue2 : String;

    FTailleBuffer: Integer;
    FLongueurQuiz: Integer;
  public
    constructor Create();

    procedure LoadFromFile(const FileName: String); override;
    procedure SaveToFile(const FileName: String); override;
    procedure Assign(Source: TPersistent); override;

    property Langue1: String read FLangue1 write FLangue1;
    property Langue2: String read FLangue2 write FLangue2;

    property TailleBuffer: Integer read FTailleBuffer write FTailleBuffer;
    property LongueurQuiz: Integer read FLongueurQuiz write FLongueurQuiz;
  end;

implementation

uses SysUtils;

{ TQuizz }

procedure TQuizz.Assign(Source: TPersistent);
begin
  inherited;
  if(Source is TQuizz) then begin
    FLangue1 := (Source as TQuizz).FLangue1;
    FLangue2 := (Source as TQuizz).FLangue2;

    FTailleBuffer := (Source as TQuizz).FTailleBuffer;
    FLongueurQuiz := (Source as TQuizz).FLongueurQuiz;
  end;
end;

constructor TQuizz.Create;
begin
  inherited;
  FTailleBuffer := 50;
  FLongueurQuiz := 1000;
end;

procedure TQuizz.LoadFromFile(const FileName: String);
var IniF: TIniFile;
    List: TStringList;
    I   : Integer;
begin
  Clear;
  IniF := nil;
  List := nil;
  try
    IniF := TIniFile.Create(FileName);
    List := TStringList.Create;
    FLangue1 := IniF.ReadString('Langues', 'Langue 1', '');
    FLangue2 := IniF.ReadString('Langues', 'Langue 2', '');

    FTailleBuffer := IniF.ReadInteger('Options', 'Taille Buffer', 50);
    FLongueurQuiz := IniF.ReadInteger('Options', 'Longueur du Quiz', 1000);

    IniF.ReadSection('Dictionnary', List);

    for I := 0 to List.Count - 1 do begin
      Add(Format('%s=%s', [List[I], IniF.ReadString('Dictionnary', List[I], '')]));
    end;
  finally
    IniF.Free;
    List.Free;
  end;
end;

procedure TQuizz.SaveToFile(const FileName: String);
var IniF: TIniFile;
    I   : Integer;
begin
  IniF := nil;
  try
    IniF := TIniFile.Create(FileName);
    IniF.WriteString('Langues', 'Langue 1', FLangue1);
    IniF.WriteString('Langues', 'Langue 2', FLangue2);

    IniF.WriteInteger('Options', 'Taille Buffer', FTailleBuffer);
    IniF.WriteInteger('Options', 'Longueur du Quiz', FLongueurQuiz);

    IniF.EraseSection('Dictionnary');

    for I := 0 to Count - 1 do begin
      IniF.WriteString('Dictionnary', Names[I], Values[Names[I]]);
    end;
  finally
    IniF.Free;
  end;
end;

end.
